Eau Duelle | Diptyque | Women | Eau De Toilette Spray 3.4 oz | PerfumeMart
Description: Eau Duelle by Diptyque Eau De Toilette Spray 3.4 oz for Women-Splash on Eau Duelle when you need a pick-me-up or are heading out on the town for a fantastic night of fun. Introduced in 2010, this spicy scent for women includes such subtle notes as ol
Keywords: Home,Fragrances for Women,E,Eau Duelle by Diptyque,Buy Eau Duelle Diptyque, Perfume

0 item(s) / Total: $0
# | A | B | C | D | E | F | G | H
I | J | K | L | M | N | O | P | Q
R | S | T | U | V | W | X | Y | Z
# | A | B | C | D | E | F | G | H
I | J | K | L | M | N | O | P | Q
R | S | T | U | V | W | X | Y | Z
| New Arrivals
| New Perfume in 2015
| Fragrances for Women
| Fragrances for Men
| Fragrances for Unisex
| Fragrances for Kids
| Mens After Shaves
| Celebrity Fragrances
| Gift Sets
| Hard To Find
| Testers
| Vials and Samples
Home>Fragrances for Women>E>Eau Duelle by Diptyque
Eau Duelle by Diptyque Eau De Toilette Spray 3.4 oz for Women |
Eau Duelle by Diptyque |  |
Brand: Eau Duelle
Designer: Diptyque
Gender: Women
Description:
Splash on Eau Duelle when you need a pick-me-up or are heading out on the town for a fantastic night of fun. Introduced in 2010, this spicy scent for women includes such subtle notes as olibanum and juniper, with hints of bergamot, elemi resin and cardamo
| Email a friend
| Whats your story? Tell us what makes this item Special for you
Price
Retail Price: $125.00
Your Savings: $11.05
Your Price: $113.95
Availability: |  | In Stock
Share |
Quantity |  |
| Add to Wish List
Description
Splash on Eau Duelle when you need a pick-me-up or are heading out on the town for a fantastic night of fun. Introduced in 2010, this spicy scent for women includes such subtle notes as olibanum and juniper, with hints of bergamot, elemi resin and cardamo
Related Items
Eau Duelle by Diptyque Eau De Parfum Spray 2.5 oz for Women
| 0 Review(s)
Your Price: $122.05
Recently Viewed Items |
15% Off w/ Purchase of 3 or More Items 10% Off w/ Purchase of 2 Items Free Shipping ALWAYS
| Fendi Furiosa by Fendi Body Lotion 6.7 oz for Women
$30.20
more details
Bvlgari Aqua Divina by Bvlgari Eau De Toilette Spray 2.2 oz for Women
$53.20 |
DKNY Men by Donna Karan Eau De Toilette Spray (Tester) 3.4 oz for Men
$37.14 |
Volutes by Diptyque Eau De Toilette Spray (Unisex) 3.4 oz for Women
$113.95 |
Asian Green Tea by Creed Eau De Parfum Spray 3.3 oz for Women
$228.70 |

Quick View